@@ -49,7 +49,7 @@
 // Module Includes
 #include <pyside2_qtcore_python.h>
 
-// Binded library includes
+// Bound library includes
 #include <QtGui/qopenglbuffer.h>
 #include <QtGui/qopenglframebufferobject.h>
 #include <QtGui/qvector4d.h>
@@ -230,7 +230,7 @@ enum : int {
     SBK_QFONT_IDX                                            = 80,
     SBK_QFONT_STYLEHINT_IDX                                  = 85,
     SBK_QFONT_STYLESTRATEGY_IDX                              = 86,
-    SBK_QFONT_HINTINGPREFERENCE_IDX                          = 376,
+    SBK_QFONT_HINTINGPREFERENCE_IDX                          = 377,
     SBK_QFONT_WEIGHT_IDX                                     = 87,
     SBK_QFONT_STYLE_IDX                                      = 84,
     SBK_QFONT_STRETCH_IDX                                    = 83,
@@ -438,125 +438,126 @@ enum : int {
     SBK_QREGEXPVALIDATOR_IDX                                 = 264,
     SBK_QREGION_IDX                                          = 265,
     SBK_QREGION_REGIONTYPE_IDX                               = 266,
-    SBK_QRESIZEEVENT_IDX                                     = 267,
-    SBK_QSCREEN_IDX                                          = 268,
-    SBK_QSCROLLEVENT_IDX                                     = 269,
-    SBK_QSCROLLEVENT_SCROLLSTATE_IDX                         = 270,
-    SBK_QSCROLLPREPAREEVENT_IDX                              = 271,
-    SBK_QSESSIONMANAGER_IDX                                  = 272,
-    SBK_QSESSIONMANAGER_RESTARTHINT_IDX                      = 273,
-    SBK_QSHORTCUTEVENT_IDX                                   = 274,
-    SBK_QSHOWEVENT_IDX                                       = 275,
-    SBK_QSTANDARDITEM_IDX                                    = 276,
-    SBK_QSTANDARDITEM_ITEMTYPE_IDX                           = 277,
-    SBK_QSTANDARDITEMMODEL_IDX                               = 278,
-    SBK_QSTATICTEXT_IDX                                      = 279,
-    SBK_QSTATICTEXT_PERFORMANCEHINT_IDX                      = 280,
-    SBK_QSTATUSTIPEVENT_IDX                                  = 281,
-    SBK_QSTYLEHINTS_IDX                                      = 282,
-    SBK_QSURFACE_IDX                                         = 283,
-    SBK_QSURFACE_SURFACECLASS_IDX                            = 284,
-    SBK_QSURFACE_SURFACETYPE_IDX                             = 285,
-    SBK_QSURFACEFORMAT_IDX                                   = 286,
-    SBK_QSURFACEFORMAT_FORMATOPTION_IDX                      = 288,
+    SBK_QREGULAREXPRESSIONVALIDATOR_IDX                      = 267,
+    SBK_QRESIZEEVENT_IDX                                     = 268,
+    SBK_QSCREEN_IDX                                          = 269,
+    SBK_QSCROLLEVENT_IDX                                     = 270,
+    SBK_QSCROLLEVENT_SCROLLSTATE_IDX                         = 271,
+    SBK_QSCROLLPREPAREEVENT_IDX                              = 272,
+    SBK_QSESSIONMANAGER_IDX                                  = 273,
+    SBK_QSESSIONMANAGER_RESTARTHINT_IDX                      = 274,
+    SBK_QSHORTCUTEVENT_IDX                                   = 275,
+    SBK_QSHOWEVENT_IDX                                       = 276,
+    SBK_QSTANDARDITEM_IDX                                    = 277,
+    SBK_QSTANDARDITEM_ITEMTYPE_IDX                           = 278,
+    SBK_QSTANDARDITEMMODEL_IDX                               = 279,
+    SBK_QSTATICTEXT_IDX                                      = 280,
+    SBK_QSTATICTEXT_PERFORMANCEHINT_IDX                      = 281,
+    SBK_QSTATUSTIPEVENT_IDX                                  = 282,
+    SBK_QSTYLEHINTS_IDX                                      = 283,
+    SBK_QSURFACE_IDX                                         = 284,
+    SBK_QSURFACE_SURFACECLASS_IDX                            = 285,
+    SBK_QSURFACE_SURFACETYPE_IDX                             = 286,
+    SBK_QSURFACEFORMAT_IDX                                   = 287,
+    SBK_QSURFACEFORMAT_FORMATOPTION_IDX                      = 289,
     SBK_QFLAGS_QSURFACEFORMAT_FORMATOPTION_IDX               = 71,
-    SBK_QSURFACEFORMAT_SWAPBEHAVIOR_IDX                      = 291,
-    SBK_QSURFACEFORMAT_RENDERABLETYPE_IDX                    = 290,
-    SBK_QSURFACEFORMAT_OPENGLCONTEXTPROFILE_IDX              = 289,
-    SBK_QSURFACEFORMAT_COLORSPACE_IDX                        = 287,
-    SBK_QSYNTAXHIGHLIGHTER_IDX                               = 292,
-    SBK_QTABLETEVENT_IDX                                     = 293,
-    SBK_QTABLETEVENT_TABLETDEVICE_IDX                        = 295,
-    SBK_QTABLETEVENT_POINTERTYPE_IDX                         = 294,
-    SBK_QTEXTBLOCK_IDX                                       = 296,
-    SBK_QTEXTBLOCK_ITERATOR_IDX                              = 297,
-    SBK_QTEXTBLOCKFORMAT_IDX                                 = 298,
-    SBK_QTEXTBLOCKFORMAT_LINEHEIGHTTYPES_IDX                 = 377,
-    SBK_QTEXTBLOCKFORMAT_MARKERTYPE_IDX                      = 299,
-    SBK_QTEXTBLOCKGROUP_IDX                                  = 300,
-    SBK_QTEXTBLOCKUSERDATA_IDX                               = 301,
-    SBK_QTEXTCHARFORMAT_IDX                                  = 302,
-    SBK_QTEXTCHARFORMAT_VERTICALALIGNMENT_IDX                = 305,
-    SBK_QTEXTCHARFORMAT_UNDERLINESTYLE_IDX                   = 304,
-    SBK_QTEXTCHARFORMAT_FONTPROPERTIESINHERITANCEBEHAVIOR_IDX = 303,
-    SBK_QTEXTCURSOR_IDX                                      = 306,
-    SBK_QTEXTCURSOR_MOVEMODE_IDX                             = 307,
-    SBK_QTEXTCURSOR_MOVEOPERATION_IDX                        = 308,
-    SBK_QTEXTCURSOR_SELECTIONTYPE_IDX                        = 309,
-    SBK_QTEXTDOCUMENT_IDX                                    = 310,
-    SBK_QTEXTDOCUMENT_METAINFORMATION_IDX                    = 313,
-    SBK_QTEXTDOCUMENT_MARKDOWNFEATURE_IDX                    = 312,
+    SBK_QSURFACEFORMAT_SWAPBEHAVIOR_IDX                      = 292,
+    SBK_QSURFACEFORMAT_RENDERABLETYPE_IDX                    = 291,
+    SBK_QSURFACEFORMAT_OPENGLCONTEXTPROFILE_IDX              = 290,
+    SBK_QSURFACEFORMAT_COLORSPACE_IDX                        = 288,
+    SBK_QSYNTAXHIGHLIGHTER_IDX                               = 293,
+    SBK_QTABLETEVENT_IDX                                     = 294,
+    SBK_QTABLETEVENT_TABLETDEVICE_IDX                        = 296,
+    SBK_QTABLETEVENT_POINTERTYPE_IDX                         = 295,
+    SBK_QTEXTBLOCK_IDX                                       = 297,
+    SBK_QTEXTBLOCK_ITERATOR_IDX                              = 298,
+    SBK_QTEXTBLOCKFORMAT_IDX                                 = 299,
+    SBK_QTEXTBLOCKFORMAT_LINEHEIGHTTYPES_IDX                 = 378,
+    SBK_QTEXTBLOCKFORMAT_MARKERTYPE_IDX                      = 300,
+    SBK_QTEXTBLOCKGROUP_IDX                                  = 301,
+    SBK_QTEXTBLOCKUSERDATA_IDX                               = 302,
+    SBK_QTEXTCHARFORMAT_IDX                                  = 303,
+    SBK_QTEXTCHARFORMAT_VERTICALALIGNMENT_IDX                = 306,
+    SBK_QTEXTCHARFORMAT_UNDERLINESTYLE_IDX                   = 305,
+    SBK_QTEXTCHARFORMAT_FONTPROPERTIESINHERITANCEBEHAVIOR_IDX = 304,
+    SBK_QTEXTCURSOR_IDX                                      = 307,
+    SBK_QTEXTCURSOR_MOVEMODE_IDX                             = 308,
+    SBK_QTEXTCURSOR_MOVEOPERATION_IDX                        = 309,
+    SBK_QTEXTCURSOR_SELECTIONTYPE_IDX                        = 310,
+    SBK_QTEXTDOCUMENT_IDX                                    = 311,
+    SBK_QTEXTDOCUMENT_METAINFORMATION_IDX                    = 314,
+    SBK_QTEXTDOCUMENT_MARKDOWNFEATURE_IDX                    = 313,
     SBK_QFLAGS_QTEXTDOCUMENT_MARKDOWNFEATURE_IDX             = 73,
-    SBK_QTEXTDOCUMENT_FINDFLAG_IDX                           = 311,
+    SBK_QTEXTDOCUMENT_FINDFLAG_IDX                           = 312,
     SBK_QFLAGS_QTEXTDOCUMENT_FINDFLAG_IDX                    = 72,
-    SBK_QTEXTDOCUMENT_RESOURCETYPE_IDX                       = 314,
-    SBK_QTEXTDOCUMENT_STACKS_IDX                             = 315,
-    SBK_QTEXTDOCUMENTFRAGMENT_IDX                            = 316,
-    SBK_QTEXTDOCUMENTWRITER_IDX                              = 317,
-    SBK_QTEXTFORMAT_IDX                                      = 318,
-    SBK_QTEXTFORMAT_FORMATTYPE_IDX                           = 319,
-    SBK_QTEXTFORMAT_PROPERTY_IDX                             = 322,
-    SBK_QTEXTFORMAT_OBJECTTYPES_IDX                          = 320,
-    SBK_QTEXTFORMAT_PAGEBREAKFLAG_IDX                        = 321,
+    SBK_QTEXTDOCUMENT_RESOURCETYPE_IDX                       = 315,
+    SBK_QTEXTDOCUMENT_STACKS_IDX                             = 316,
+    SBK_QTEXTDOCUMENTFRAGMENT_IDX                            = 317,
+    SBK_QTEXTDOCUMENTWRITER_IDX                              = 318,
+    SBK_QTEXTFORMAT_IDX                                      = 319,
+    SBK_QTEXTFORMAT_FORMATTYPE_IDX                           = 320,
+    SBK_QTEXTFORMAT_PROPERTY_IDX                             = 323,
+    SBK_QTEXTFORMAT_OBJECTTYPES_IDX                          = 321,
+    SBK_QTEXTFORMAT_PAGEBREAKFLAG_IDX                        = 322,
     SBK_QFLAGS_QTEXTFORMAT_PAGEBREAKFLAG_IDX                 = 74,
-    SBK_QTEXTFRAGMENT_IDX                                    = 323,
-    SBK_QTEXTFRAME_IDX                                       = 324,
-    SBK_QTEXTFRAME_ITERATOR_IDX                              = 325,
-    SBK_QTEXTFRAMEFORMAT_IDX                                 = 326,
-    SBK_QTEXTFRAMEFORMAT_POSITION_IDX                        = 328,
-    SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX                     = 327,
-    SBK_QTEXTIMAGEFORMAT_IDX                                 = 329,
-    SBK_QTEXTINLINEOBJECT_IDX                                = 330,
-    SBK_QTEXTITEM_IDX                                        = 331,
-    SBK_QTEXTITEM_RENDERFLAG_IDX                             = 332,
+    SBK_QTEXTFRAGMENT_IDX                                    = 324,
+    SBK_QTEXTFRAME_IDX                                       = 325,
+    SBK_QTEXTFRAME_ITERATOR_IDX                              = 326,
+    SBK_QTEXTFRAMEFORMAT_IDX                                 = 327,
+    SBK_QTEXTFRAMEFORMAT_POSITION_IDX                        = 329,
+    SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX                     = 328,
+    SBK_QTEXTIMAGEFORMAT_IDX                                 = 330,
+    SBK_QTEXTINLINEOBJECT_IDX                                = 331,
+    SBK_QTEXTITEM_IDX                                        = 332,
+    SBK_QTEXTITEM_RENDERFLAG_IDX                             = 333,
     SBK_QFLAGS_QTEXTITEM_RENDERFLAG_IDX                      = 75,
-    SBK_QTEXTLAYOUT_IDX                                      = 333,
-    SBK_QTEXTLAYOUT_CURSORMODE_IDX                           = 334,
-    SBK_QTEXTLAYOUT_FORMATRANGE_IDX                          = 335,
-    SBK_QTEXTLENGTH_IDX                                      = 336,
-    SBK_QTEXTLENGTH_TYPE_IDX                                 = 337,
-    SBK_QTEXTLINE_IDX                                        = 338,
-    SBK_QTEXTLINE_EDGE_IDX                                   = 340,
-    SBK_QTEXTLINE_CURSORPOSITION_IDX                         = 339,
-    SBK_QTEXTLIST_IDX                                        = 341,
-    SBK_QTEXTLISTFORMAT_IDX                                  = 342,
-    SBK_QTEXTLISTFORMAT_STYLE_IDX                            = 343,
-    SBK_QTEXTOBJECT_IDX                                      = 344,
-    SBK_QTEXTOBJECTINTERFACE_IDX                             = 345,
-    SBK_QTEXTOPTION_IDX                                      = 346,
-    SBK_QTEXTOPTION_TABTYPE_IDX                              = 349,
-    SBK_QTEXTOPTION_WRAPMODE_IDX                             = 350,
-    SBK_QTEXTOPTION_FLAG_IDX                                 = 347,
+    SBK_QTEXTLAYOUT_IDX                                      = 334,
+    SBK_QTEXTLAYOUT_CURSORMODE_IDX                           = 335,
+    SBK_QTEXTLAYOUT_FORMATRANGE_IDX                          = 336,
+    SBK_QTEXTLENGTH_IDX                                      = 337,
+    SBK_QTEXTLENGTH_TYPE_IDX                                 = 338,
+    SBK_QTEXTLINE_IDX                                        = 339,
+    SBK_QTEXTLINE_EDGE_IDX                                   = 341,
+    SBK_QTEXTLINE_CURSORPOSITION_IDX                         = 340,
+    SBK_QTEXTLIST_IDX                                        = 342,
+    SBK_QTEXTLISTFORMAT_IDX                                  = 343,
+    SBK_QTEXTLISTFORMAT_STYLE_IDX                            = 344,
+    SBK_QTEXTOBJECT_IDX                                      = 345,
+    SBK_QTEXTOBJECTINTERFACE_IDX                             = 346,
+    SBK_QTEXTOPTION_IDX                                      = 347,
+    SBK_QTEXTOPTION_TABTYPE_IDX                              = 350,
+    SBK_QTEXTOPTION_WRAPMODE_IDX                             = 351,
+    SBK_QTEXTOPTION_FLAG_IDX                                 = 348,
     SBK_QFLAGS_QTEXTOPTION_FLAG_IDX                          = 76,
-    SBK_QTEXTOPTION_TAB_IDX                                  = 348,
-    SBK_QTEXTTABLE_IDX                                       = 351,
-    SBK_QTEXTTABLECELL_IDX                                   = 352,
-    SBK_QTEXTTABLECELLFORMAT_IDX                             = 353,
-    SBK_QTEXTTABLEFORMAT_IDX                                 = 354,
-    SBK_QTOOLBARCHANGEEVENT_IDX                              = 355,
-    SBK_QTOUCHDEVICE_IDX                                     = 356,
-    SBK_QTOUCHDEVICE_DEVICETYPE_IDX                          = 358,
-    SBK_QTOUCHDEVICE_CAPABILITYFLAG_IDX                      = 357,
+    SBK_QTEXTOPTION_TAB_IDX                                  = 349,
+    SBK_QTEXTTABLE_IDX                                       = 352,
+    SBK_QTEXTTABLECELL_IDX                                   = 353,
+    SBK_QTEXTTABLECELLFORMAT_IDX                             = 354,
+    SBK_QTEXTTABLEFORMAT_IDX                                 = 355,
+    SBK_QTOOLBARCHANGEEVENT_IDX                              = 356,
+    SBK_QTOUCHDEVICE_IDX                                     = 357,
+    SBK_QTOUCHDEVICE_DEVICETYPE_IDX                          = 359,
+    SBK_QTOUCHDEVICE_CAPABILITYFLAG_IDX                      = 358,
     SBK_QFLAGS_QTOUCHDEVICE_CAPABILITYFLAG_IDX               = 77,
-    SBK_QTOUCHEVENT_IDX                                      = 359,
-    SBK_QTOUCHEVENT_TOUCHPOINT_IDX                           = 360,
-    SBK_QTOUCHEVENT_TOUCHPOINT_INFOFLAG_IDX                  = 361,
+    SBK_QTOUCHEVENT_IDX                                      = 360,
+    SBK_QTOUCHEVENT_TOUCHPOINT_IDX                           = 361,
+    SBK_QTOUCHEVENT_TOUCHPOINT_INFOFLAG_IDX                  = 362,
     SBK_QFLAGS_QTOUCHEVENT_TOUCHPOINT_INFOFLAG_IDX           = 78,
-    SBK_QTRANSFORM_IDX                                       = 362,
-    SBK_QTRANSFORM_TRANSFORMATIONTYPE_IDX                    = 363,
-    SBK_QVALIDATOR_IDX                                       = 364,
-    SBK_QVALIDATOR_STATE_IDX                                 = 365,
-    SBK_QVECTOR2D_IDX                                        = 366,
-    SBK_QVECTOR3D_IDX                                        = 367,
-    SBK_QVECTOR4D_IDX                                        = 368,
-    SBK_QWHATSTHISCLICKEDEVENT_IDX                           = 369,
-    SBK_QWHEELEVENT_IDX                                      = 370,
-    SBK_QWINDOW_IDX                                          = 371,
-    SBK_QWINDOW_VISIBILITY_IDX                               = 373,
-    SBK_QWINDOW_ANCESTORMODE_IDX                             = 372,
-    SBK_QWINDOWSTATECHANGEEVENT_IDX                          = 374,
-    SBK_QtGuiQT_IDX                                          = 375,
-    SBK_QtGui_IDX_COUNT                                      = 378
+    SBK_QTRANSFORM_IDX                                       = 363,
+    SBK_QTRANSFORM_TRANSFORMATIONTYPE_IDX                    = 364,
+    SBK_QVALIDATOR_IDX                                       = 365,
+    SBK_QVALIDATOR_STATE_IDX                                 = 366,
+    SBK_QVECTOR2D_IDX                                        = 367,
+    SBK_QVECTOR3D_IDX                                        = 368,
+    SBK_QVECTOR4D_IDX                                        = 369,
+    SBK_QWHATSTHISCLICKEDEVENT_IDX                           = 370,
+    SBK_QWHEELEVENT_IDX                                      = 371,
+    SBK_QWINDOW_IDX                                          = 372,
+    SBK_QWINDOW_VISIBILITY_IDX                               = 374,
+    SBK_QWINDOW_ANCESTORMODE_IDX                             = 373,
+    SBK_QWINDOWSTATECHANGEEVENT_IDX                          = 375,
+    SBK_QtGuiQT_IDX                                          = 376,
+    SBK_QtGui_IDX_COUNT                                      = 379
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide2_QtGuiTypes;
@@ -894,6 +895,7 @@ template<> inline PyTypeObject *SbkType< ::QRawFont >() { return reinterpret_cas
 template<> inline PyTypeObject *SbkType< ::QRegExpValidator >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtGuiTypes[SBK_QREGEXPVALIDATOR_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QRegion::RegionType >() { return SbkPySide2_QtGuiTypes[SBK_QREGION_REGIONTYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QRegion >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtGuiTypes[SBK_QREGION_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QRegularExpressionValidator >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtGuiTypes[SBK_QREGULAREXPRESSIONVALIDATOR_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QResizeEvent >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtGuiTypes[SBK_QRESIZEEVENT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QScreen >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtGuiTypes[SBK_QSCREEN_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QScrollEvent::ScrollState >() { return SbkPySide2_QtGuiTypes[SBK_QSCROLLEVENT_SCROLLSTATE_IDX]; }
