@@ -189,23 +189,25 @@ enum : int {
     SBK_QNETWORKREQUEST_LOADCONTROL_IDX                      = 81,
     SBK_QNETWORKREQUEST_PRIORITY_IDX                         = 82,
     SBK_QNETWORKREQUEST_REDIRECTPOLICY_IDX                   = 83,
-    SBK_QNETWORKSESSION_IDX                                  = 84,
-    SBK_QNETWORKSESSION_STATE_IDX                            = 86,
-    SBK_QNETWORKSESSION_SESSIONERROR_IDX                     = 85,
-    SBK_QNETWORKSESSION_USAGEPOLICY_IDX                      = 87,
+    SBK_QNETWORKREQUEST_TRANSFERTIMEOUTCONSTANT_IDX          = 84,
+    SBK_QNETWORKSESSION_IDX                                  = 85,
+    SBK_QNETWORKSESSION_STATE_IDX                            = 87,
+    SBK_QNETWORKSESSION_SESSIONERROR_IDX                     = 86,
+    SBK_QNETWORKSESSION_USAGEPOLICY_IDX                      = 88,
     SBK_QFLAGS_QNETWORKSESSION_USAGEPOLICY_IDX               = 30,
-    SBK_QOCSPRESPONSE_IDX                                    = 89,
-    SBK_QtNetworkQPASSWORDDIGESTOR_IDX                       = 91,
-    SBK_QtNetworkQSSL_IDX                                    = 94,
-    SBK_QSSL_KEYTYPE_IDX                                     = 98,
-    SBK_QSSL_ENCODINGFORMAT_IDX                              = 96,
-    SBK_QSSL_KEYALGORITHM_IDX                                = 97,
-    SBK_QSSL_ALTERNATIVENAMEENTRYTYPE_IDX                    = 95,
-    SBK_QSSL_SSLPROTOCOL_IDX                                 = 100,
-    SBK_QSSL_SSLOPTION_IDX                                   = 99,
+    SBK_QOCSPRESPONSE_IDX                                    = 90,
+    SBK_QtNetworkQPASSWORDDIGESTOR_IDX                       = 92,
+    SBK_QtNetworkQSSL_IDX                                    = 93,
+    SBK_QSSL_KEYTYPE_IDX                                     = 97,
+    SBK_QSSL_ENCODINGFORMAT_IDX                              = 95,
+    SBK_QSSL_KEYALGORITHM_IDX                                = 96,
+    SBK_QSSL_ALTERNATIVENAMEENTRYTYPE_IDX                    = 94,
+    SBK_QSSL_SSLPROTOCOL_IDX                                 = 99,
+    SBK_QSSL_SSLOPTION_IDX                                   = 98,
     SBK_QFLAGS_QSSL_SSLOPTION_IDX                            = 31,
-    SBK_QSSLCERTIFICATE_IDX                                  = 101,
+    SBK_QSSLCERTIFICATE_IDX                                  = 100,
     SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX                      = 102,
+    SBK_QSSLCERTIFICATE_PATTERNSYNTAX_IDX                    = 101,
     SBK_QSSLCERTIFICATEEXTENSION_IDX                         = 103,
     SBK_QSSLCIPHER_IDX                                       = 104,
     SBK_QSSLCONFIGURATION_IDX                                = 105,
@@ -223,8 +225,8 @@ enum : int {
     SBK_QTCPSOCKET_IDX                                       = 117,
     SBK_QUDPSOCKET_IDX                                       = 118,
     SBK_QDTLSERROR_IDX                                       = 20,
-    SBK_QOCSPCERTIFICATESTATUS_IDX                           = 88,
-    SBK_QOCSPREVOCATIONREASON_IDX                            = 90,
+    SBK_QOCSPCERTIFICATESTATUS_IDX                           = 89,
+    SBK_QOCSPREVOCATIONREASON_IDX                            = 91,
     SBK_QtNetwork_IDX_COUNT                                  = 119
 };
 // This variable stores all Python types exported by this module.
@@ -361,6 +363,7 @@ template<> inline PyTypeObject *SbkType< ::QNetworkRequest::CacheLoadControl >()
 template<> inline PyTypeObject *SbkType< ::QNetworkRequest::LoadControl >() { return SbkPySide2_QtNetworkTypes[SBK_QNETWORKREQUEST_LOADCONTROL_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkRequest::Priority >() { return SbkPySide2_QtNetworkTypes[SBK_QNETWORKREQUEST_PRIORITY_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkRequest::RedirectPolicy >() { return SbkPySide2_QtNetworkTypes[SBK_QNETWORKREQUEST_REDIRECTPOLICY_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QNetworkRequest::TransferTimeoutConstant >() { return SbkPySide2_QtNetworkTypes[SBK_QNETWORKREQUEST_TRANSFERTIMEOUTCONSTANT_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkRequest >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtNetworkTypes[SBK_QNETWORKREQUEST_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkSession::State >() { return SbkPySide2_QtNetworkTypes[SBK_QNETWORKSESSION_STATE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkSession::SessionError >() { return SbkPySide2_QtNetworkTypes[SBK_QNETWORKSESSION_SESSIONERROR_IDX]; }
@@ -376,6 +379,7 @@ template<> inline PyTypeObject *SbkType< ::QSsl::SslProtocol >() { return SbkPyS
 template<> inline PyTypeObject *SbkType< ::QSsl::SslOption >() { return SbkPySide2_QtNetworkTypes[SBK_QSSL_SSLOPTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QSsl::SslOption> >() { return SbkPySide2_QtNetworkTypes[SBK_QFLAGS_QSSL_SSLOPTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslCertificate::SubjectInfo >() { return SbkPySide2_QtNetworkTypes[SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QSslCertificate::PatternSyntax >() { return SbkPySide2_QtNetworkTypes[SBK_QSSLCERTIFICATE_PATTERNSYNTAX_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslCertificate >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtNetworkTypes[SBK_QSSLCERTIFICATE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSslCertificateExtension >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtNetworkTypes[SBK_QSSLCERTIFICATEEXTENSION_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSslCipher >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtNetworkTypes[SBK_QSSLCIPHER_IDX]); }
